@@ -32,7 +32,7 @@ class CreateService(command.ShowOne):
     _description = _("Create new service")
 
     def get_parser(self, prog_name):
-        parser = super(CreateService, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'type',
             metavar='<type>',
@@ -71,7 +71,7 @@ class DeleteService(command.Command):
     _description = _("Delete service(s)")
 
     def get_parser(self, prog_name):
-        parser = super(DeleteService, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'services',
             metavar='<service>',
@@ -90,14 +90,20 @@ class DeleteService(command.Command):
                 identity_client.services.delete(service.id)
             except Exception as e:
                 result += 1
-                LOG.error(_("Failed to delete service with "
-                          "name or ID '%(service)s': %(e)s"),
-                          {'service': service, 'e': e})
+                LOG.error(
+                    _(
+                        "Failed to delete service with "
+                        "name or ID '%(service)s': %(e)s"
+                    ),
+                    {'service': service, 'e': e},
+                )
 
         if result > 0:
             total = len(parsed_args.services)
-            msg = (_("%(result)s of %(total)s services failed "
-                   "to delete.") % {'result': result, 'total': total})
+            msg = _("%(result)s of %(total)s services failed to delete.") % {
+                'result': result,
+                'total': total,
+            }
             raise exceptions.CommandError(msg)
 
 
@@ -105,7 +111,7 @@ class ListService(command.Lister):
     _description = _("List services")
 
     def get_parser(self, prog_name):
-        parser = super(ListService, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             '--long',
             action='store_true',
@@ -115,11 +121,9 @@ class ListService(command.Lister):
         return parser
 
     def take_action(self, parsed_args):
-
+        columns: tuple[str, ...] = ('ID', 'Name', 'Type')
         if parsed_args.long:
-            columns = ('ID', 'Name', 'Type', 'Description')
-        else:
-            columns = ('ID', 'Name', 'Type')
+            columns += ('Description',)
         data = self.app.client_manager.identity.services.list()
         return (
             columns,
@@ -131,7 +135,7 @@ class ShowService(command.ShowOne):
     _description = _("Display service details")
 
     def get_parser(self, prog_name):
-        parser = super(ShowService, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'service',
             metavar='<service>',
@@ -151,15 +155,17 @@ class ShowService(command.ShowOne):
 
         if parsed_args.catalog:
             endpoints = auth_ref.service_catalog.get_endpoints(
-                service_type=parsed_args.service)
-            for (service, service_endpoints) in endpoints.items():
+                service_type=parsed_args.service
+            )
+            for service, service_endpoints in endpoints.items():
                 if service_endpoints:
                     info = {"type": service}
                     info.update(service_endpoints[0])
                     return zip(*sorted(info.items()))
 
-            msg = _("No service catalog with a type, name or ID of '%s' "
-                    "exists.") % (parsed_args.service)
+            msg = _(
+                "No service catalog with a type, name or ID of '%s' exists."
+            ) % (parsed_args.service)
             raise exceptions.CommandError(msg)
         else:
             service = common.find_service(identity_client, parsed_args.service)
