@@ -25,11 +25,34 @@ from openstackclient.i18n import _
 LOG = logging.getLogger(__name__)
 
 
+def _format_service_provider(sp):
+    column_headers = (
+        'id',
+        'enabled',
+        'description',
+        'auth_url',
+        'sp_url',
+        'relay_state_prefix',
+    )
+    columns = (
+        'id',
+        'is_enabled',
+        'description',
+        'auth_url',
+        'sp_url',
+        'relay_state_prefix',
+    )
+    return (
+        column_headers,
+        utils.get_item_properties(sp, columns),
+    )
+
+
 class CreateServiceProvider(command.ShowOne):
     _description = _("Create new service provider")
 
     def get_parser(self, prog_name):
-        parser = super(CreateServiceProvider, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'service_provider_id',
             metavar='<name>',
@@ -39,8 +62,10 @@ class CreateServiceProvider(command.ShowOne):
             '--auth-url',
             metavar='<auth-url>',
             required=True,
-            help=_('Authentication URL of remote federated service provider '
-                   '(required)'),
+            help=_(
+                'Authentication URL of remote federated service provider '
+                '(required)'
+            ),
         )
         parser.add_argument(
             '--description',
@@ -51,21 +76,22 @@ class CreateServiceProvider(command.ShowOne):
             '--service-provider-url',
             metavar='<sp-url>',
             required=True,
-            help=_('A service URL where SAML assertions are being sent '
-                   '(required)'),
+            help=_(
+                'A service URL where SAML assertions are being sent (required)'
+            ),
         )
 
         enable_service_provider = parser.add_mutually_exclusive_group()
         enable_service_provider.add_argument(
             '--enable',
-            dest='enabled',
+            dest='is_enabled',
             action='store_true',
             default=True,
             help=_('Enable the service provider (default)'),
         )
         enable_service_provider.add_argument(
             '--disable',
-            dest='enabled',
+            dest='is_enabled',
             action='store_false',
             help=_('Disable the service provider'),
         )
@@ -73,23 +99,34 @@ class CreateServiceProvider(command.ShowOne):
         return parser
 
     def take_action(self, parsed_args):
-        service_client = self.app.client_manager.identity
-        sp = service_client.federation.service_providers.create(
-            id=parsed_args.service_provider_id,
-            auth_url=parsed_args.auth_url,
-            description=parsed_args.description,
-            enabled=parsed_args.enabled,
-            sp_url=parsed_args.service_provider_url)
+        service_client = self.app.client_manager.sdk_connection.identity
 
-        sp._info.pop('links', None)
-        return zip(*sorted(sp._info.items()))
+        kwargs = {}
+
+        kwargs = {'id': parsed_args.service_provider_id}
+
+        if parsed_args.is_enabled is not None:
+            kwargs['is_enabled'] = parsed_args.is_enabled
+
+        if parsed_args.description:
+            kwargs['description'] = parsed_args.description
+
+        if parsed_args.auth_url:
+            kwargs['auth_url'] = parsed_args.auth_url
+
+        if parsed_args.service_provider_url:
+            kwargs['sp_url'] = parsed_args.service_provider_url
+
+        sp = service_client.create_service_provider(**kwargs)
+
+        return _format_service_provider(sp)
 
 
 class DeleteServiceProvider(command.Command):
     _description = _("Delete service provider(s)")
 
     def get_parser(self, prog_name):
-        parser = super(DeleteServiceProvider, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'service_provider',
             metavar='<service-provider>',
@@ -99,21 +136,26 @@ class DeleteServiceProvider(command.Command):
         return parser
 
     def take_action(self, parsed_args):
-        service_client = self.app.client_manager.identity
+        service_client = self.app.client_manager.sdk_connection.identity
         result = 0
         for i in parsed_args.service_provider:
             try:
-                service_client.federation.service_providers.delete(i)
+                service_client.delete_service_provider(i)
             except Exception as e:
                 result += 1
-                LOG.error(_("Failed to delete service provider with "
-                          "name or ID '%(provider)s': %(e)s"),
-                          {'provider': i, 'e': e})
+                LOG.error(
+                    _(
+                        "Failed to delete service provider with "
+                        "name or ID '%(provider)s': %(e)s"
+                    ),
+                    {'provider': i, 'e': e},
+                )
 
         if result > 0:
             total = len(parsed_args.service_provider)
-            msg = (_("%(result)s of %(total)s service providers failed"
-                   " to delete.") % {'result': result, 'total': total})
+            msg = _(
+                "%(result)s of %(total)s service providers failed to delete."
+            ) % {'result': result, 'total': total}
             raise exceptions.CommandError(msg)
 
 
@@ -121,22 +163,36 @@ class ListServiceProvider(command.Lister):
     _description = _("List service providers")
 
     def take_action(self, parsed_args):
-        service_client = self.app.client_manager.identity
-        data = service_client.federation.service_providers.list()
+        service_client = self.app.client_manager.sdk_connection.identity
+        data = service_client.service_providers()
 
-        column_headers = ('ID', 'Enabled', 'Description', 'Auth URL')
-        return (column_headers,
-                (utils.get_item_properties(
-                    s, column_headers,
-                    formatters={},
-                ) for s in data))
+        column_headers = (
+            'ID',
+            'Enabled',
+            'Description',
+            'Auth URL',
+            'Service Provider URL',
+            'Relay State Prefix',
+        )
+        columns = (
+            'id',
+            'is_enabled',
+            'description',
+            'auth_url',
+            'sp_url',
+            'relay_state_prefix',
+        )
+        return (
+            column_headers,
+            (utils.get_item_properties(s, columns) for s in data),
+        )
 
 
-class SetServiceProvider(command.Command):
+class SetServiceProvider(command.ShowOne):
     _description = _("Set service provider properties")
 
     def get_parser(self, prog_name):
-        parser = super(SetServiceProvider, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'service_provider',
             metavar='<service-provider>',
@@ -145,8 +201,9 @@ class SetServiceProvider(command.Command):
         parser.add_argument(
             '--auth-url',
             metavar='<auth-url>',
-            help=_('New Authentication URL of remote '
-                   'federated service provider'),
+            help=_(
+                'New Authentication URL of remote federated service provider'
+            ),
         )
 
         parser.add_argument(
@@ -162,39 +219,50 @@ class SetServiceProvider(command.Command):
         enable_service_provider = parser.add_mutually_exclusive_group()
         enable_service_provider.add_argument(
             '--enable',
+            dest='is_enabled',
             action='store_true',
+            default=None,
             help=_('Enable the service provider'),
         )
         enable_service_provider.add_argument(
             '--disable',
-            action='store_true',
+            dest='is_enabled',
+            action='store_false',
+            default=None,
             help=_('Disable the service provider'),
         )
         return parser
 
     def take_action(self, parsed_args):
-        federation_client = self.app.client_manager.identity.federation
+        service_client = self.app.client_manager.sdk_connection.identity
 
-        enabled = None
-        if parsed_args.enable is True:
-            enabled = True
-        elif parsed_args.disable is True:
-            enabled = False
+        kwargs = {}
 
-        federation_client.service_providers.update(
+        if parsed_args.is_enabled is not None:
+            kwargs['is_enabled'] = parsed_args.is_enabled
+
+        if parsed_args.description:
+            kwargs['description'] = parsed_args.description
+
+        if parsed_args.auth_url:
+            kwargs['auth_url'] = parsed_args.auth_url
+
+        if parsed_args.service_provider_url:
+            kwargs['sp_url'] = parsed_args.service_provider_url
+
+        service_provider = service_client.update_service_provider(
             parsed_args.service_provider,
-            enabled=enabled,
-            description=parsed_args.description,
-            auth_url=parsed_args.auth_url,
-            sp_url=parsed_args.service_provider_url,
+            **kwargs,
         )
 
+        return _format_service_provider(service_provider)
+
 
 class ShowServiceProvider(command.ShowOne):
     _description = _("Display service provider details")
 
     def get_parser(self, prog_name):
-        parser = super(ShowServiceProvider, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'service_provider',
             metavar='<service-provider>',
@@ -203,11 +271,10 @@ class ShowServiceProvider(command.ShowOne):
         return parser
 
     def take_action(self, parsed_args):
-        service_client = self.app.client_manager.identity
-        service_provider = utils.find_resource(
-            service_client.federation.service_providers,
+        service_client = self.app.client_manager.sdk_connection.identity
+        service_provider = service_client.find_service_provider(
             parsed_args.service_provider,
-            id=parsed_args.service_provider)
+            ignore_missing=False,
+        )
 
-        service_provider._info.pop('links', None)
-        return zip(*sorted(service_provider._info.items()))
+        return _format_service_provider(service_provider)
