@@ -25,10 +25,9 @@ LOG = logging.getLogger(__name__)
 
 
 def _get_columns(item):
-    column_map = {}
     hidden_columns = ['location', 'tenant_id']
     return utils.get_osc_show_columns_for_sdk_resource(
-        item, column_map, hidden_columns
+        item, {}, hidden_columns
     )
 
 
@@ -66,8 +65,7 @@ class CreateConntrackHelper(command.ShowOne):
             required=True,
             metavar='<protocol>',
             help=_(
-                'The network protocol for the netfilter conntrack target '
-                'rule'
+                'The network protocol for the netfilter conntrack target rule'
             ),
         )
         parser.add_argument(
@@ -99,7 +97,7 @@ class DeleteConntrackHelper(command.Command):
         parser.add_argument(
             'router',
             metavar='<router>',
-            help=_('Router that the conntrack helper belong to'),
+            help=_('Router that the conntrack helper belongs to'),
         )
         parser.add_argument(
             'conntrack_helper_id',
@@ -147,7 +145,7 @@ class ListConntrackHelper(command.Lister):
         parser.add_argument(
             'router',
             metavar='<router>',
-            help=_('Router that the conntrack helper belong to'),
+            help=_('Router that the conntrack helper belongs to'),
         )
         parser.add_argument(
             '--helper',
@@ -158,8 +156,7 @@ class ListConntrackHelper(command.Lister):
             '--protocol',
             metavar='<protocol>',
             help=_(
-                'The network protocol for the netfilter conntrack target '
-                'rule'
+                'The network protocol for the netfilter conntrack target rule'
             ),
         )
         parser.add_argument(
@@ -210,7 +207,7 @@ class SetConntrackHelper(command.Command):
         parser.add_argument(
             'router',
             metavar='<router>',
-            help=_('Router that the conntrack helper belong to'),
+            help=_('Router that the conntrack helper belongs to'),
         )
         parser.add_argument(
             'conntrack_helper_id',
@@ -226,8 +223,7 @@ class SetConntrackHelper(command.Command):
             '--protocol',
             metavar='<protocol>',
             help=_(
-                'The network protocol for the netfilter conntrack target '
-                'rule'
+                'The network protocol for the netfilter conntrack target rule'
             ),
         )
         parser.add_argument(
@@ -245,7 +241,7 @@ class SetConntrackHelper(command.Command):
             client.update_conntrack_helper(
                 parsed_args.conntrack_helper_id,
                 attrs.pop('router_id'),
-                **attrs
+                **attrs,
             )
 
 
@@ -257,7 +253,7 @@ class ShowConntrackHelper(command.ShowOne):
         parser.add_argument(
             'router',
             metavar='<router>',
-            help=_('Router that the conntrack helper belong to'),
+            help=_('Router that the conntrack helper belongs to'),
         )
         parser.add_argument(
             'conntrack_helper_id',
