@@ -18,6 +18,7 @@ import collections
 import copy
 import json
 import logging
+import typing as ty
 
 from cliff import columns as cliff_columns
 from osc_lib.cli import format_columns
@@ -75,7 +76,7 @@ def _get_columns(item):
     }
     if hasattr(item, 'interfaces_info'):
         column_map['interfaces_info'] = 'interfaces_info'
-    invisible_columns = ['location']
+    invisible_columns = ['location', 'tenant_id']
     if item.is_ha is None:
         invisible_columns.append('is_ha')
         column_map.pop('is_ha')
@@ -104,21 +105,21 @@ def _passed_multiple_gateways(extension_supported, external_gateways):
 
 
 def _get_external_gateway_attrs(client_manager, parsed_args):
-    attrs = {}
+    attrs: dict[str, ty.Any] = {}
 
     if parsed_args.external_gateways:
         external_gateways: collections.defaultdict[str, list[dict]] = (
             collections.defaultdict(list)
         )
         n_client = client_manager.network
-        first_network_id = None
+        first_network_id = ''
 
         for gw_net_name_or_id in parsed_args.external_gateways:
             gateway_info = {}
             gw_net = n_client.find_network(
                 gw_net_name_or_id, ignore_missing=False
             )
-            if first_network_id is None:
+            if not first_network_id:
                 first_network_id = gw_net.id
             gateway_info['network_id'] = gw_net.id
             if 'disable_snat' in parsed_args and parsed_args.disable_snat:
@@ -146,7 +147,7 @@ def _get_external_gateway_attrs(client_manager, parsed_args):
             for ip_spec in parsed_args.fixed_ips:
                 # If there is only one gateway, this value will represent the
                 # network ID for it, otherwise it will be overridden.
-                ip_net_id = first_network_id
+                ip_net_id: str = first_network_id
 
                 if ip_spec.get('subnet', False):
                     subnet_name_id = ip_spec.pop('subnet')
@@ -164,10 +165,13 @@ def _get_external_gateway_attrs(client_manager, parsed_args):
                     'subnet_id' in ip_spec
                     and ip_net_id not in external_gateways
                 ):
-                    msg = _(
-                        'Subnet %s does not belong to any of the networks '
-                        'provided for --external-gateway.'
-                    ) % (ip_spec['subnet_id'])
+                    msg = (
+                        _(
+                            'Subnet %s does not belong to any of the networks '
+                            'provided for --external-gateway.'
+                        )
+                        % (ip_spec['subnet_id'])
+                    )
                     raise exceptions.CommandError(msg)
                 for gw_info in external_gateways[ip_net_id]:
                     if 'external_fixed_ips' not in gw_info:
@@ -234,6 +238,9 @@ def _get_attrs(client_manager, parsed_args):
     if 'flavor_id' in parsed_args and parsed_args.flavor_id is not None:
         flavor = n_client.find_flavor(parsed_args.flavor_id)
         attrs['flavor_id'] = flavor.id
+    elif 'flavor' in parsed_args and parsed_args.flavor is not None:
+        flavor = n_client.find_flavor(parsed_args.flavor, ignore_missing=False)
+        attrs['flavor_id'] = flavor.id
 
     for attr in ('enable_default_route_bfd', 'enable_default_route_ecmp'):
         value = getattr(parsed_args, attr, None)
@@ -252,7 +259,7 @@ def _parser_add_bfd_ecmp_arguments(parser):
         action='store_true',
         help=_(
             "Enable BFD sessions for default routes inferred from "
-            "the external gateway port subnets for this router."
+            "the external gateway port subnets for this router"
         ),
     )
     parser.add_argument(
@@ -262,7 +269,7 @@ def _parser_add_bfd_ecmp_arguments(parser):
         action='store_false',
         help=_(
             "Disable BFD sessions for default routes inferred from "
-            "the external gateway port subnets for this router."
+            "the external gateway port subnets for this router"
         ),
     )
     parser.add_argument(
@@ -272,7 +279,7 @@ def _parser_add_bfd_ecmp_arguments(parser):
         action='store_true',
         help=_(
             "Add ECMP default routes if multiple are available via "
-            "different gateway ports."
+            "different gateway ports"
         ),
     )
     parser.add_argument(
@@ -280,7 +287,7 @@ def _parser_add_bfd_ecmp_arguments(parser):
         dest='enable_default_route_ecmp',
         default=None,
         action='store_false',
-        help=_("Add default route only for first gateway port."),
+        help=_("Add default route only for first gateway port"),
     )
 
 
@@ -361,7 +368,7 @@ class AddExtraRoutesToRouter(command.ShowOne):
             metavar='<router>',
             help=_(
                 "Router to which extra static routes "
-                "will be added (name or ID)."
+                "will be added (name or ID)"
             ),
         )
         parser.add_argument(
@@ -376,7 +383,7 @@ class AddExtraRoutesToRouter(command.ShowOne):
                 "destination: destination subnet (in CIDR notation), "
                 "gateway: nexthop IP address. "
                 "Repeat option to add multiple routes. "
-                "Trying to add a route that's already present "
+                "Trying to add a route that is already present "
                 "(exactly, including destination and nexthop) "
                 "in the routing table is allowed and is considered "
                 "a successful operation."
@@ -412,7 +419,7 @@ class RemoveExtraRoutesFromRouter(command.ShowOne):
             metavar='<router>',
             help=_(
                 "Router from which extra static routes "
-                "will be removed (name or ID)."
+                "will be removed (name or ID)"
             ),
         )
         parser.add_argument(
@@ -427,7 +434,7 @@ class RemoveExtraRoutesFromRouter(command.ShowOne):
                 "destination: destination subnet (in CIDR notation), "
                 "gateway: nexthop IP address. "
                 "Repeat option to remove multiple routes. "
-                "Trying to remove a route that's already missing "
+                "Trying to remove a route that is already missing "
                 "(fully, including destination and nexthop) "
                 "from the routing table is allowed and is considered "
                 "a successful operation."
@@ -519,9 +526,9 @@ class CreateRouter(command.ShowOne, common.NeutronCommandWithExtraArgs):
             metavar="<network>",
             action='append',
             help=_(
-                "External Network used as router's gateway (name or ID). "
+                "External Network used as router's gateway (name or ID) "
                 "(repeat option to set multiple gateways per router "
-                "if the L3 service plugin in use supports it)."
+                "if the L3 service plugin in use supports it)"
             ),
             dest='external_gateways',
         )
@@ -535,7 +542,7 @@ class CreateRouter(command.ShowOne, common.NeutronCommandWithExtraArgs):
                 "Desired IP and/or subnet (name or ID) "
                 "on external gateway: "
                 "subnet=<subnet>,ip-address=<ip-address> "
-                "(repeat option to set multiple fixed IP addresses)."
+                "(repeat option to set multiple fixed IP addresses)"
             ),
         )
         snat_group = parser.add_mutually_exclusive_group()
@@ -575,6 +582,11 @@ class CreateRouter(command.ShowOne, common.NeutronCommandWithExtraArgs):
             help=argparse.SUPPRESS,
         )
         _parser_add_bfd_ecmp_arguments(parser)
+        parser.add_argument(
+            '--qos-policy',
+            metavar='<qos-policy>',
+            help=_('Attach QoS policy to router gateway IPs'),
+        )
 
         return parser
 
@@ -597,6 +609,13 @@ class CreateRouter(command.ShowOne, common.NeutronCommandWithExtraArgs):
             )
             raise exceptions.CommandError(msg)
 
+        if parsed_args.qos_policy and not parsed_args.external_gateways:
+            msg = _(
+                "You must specify '--external-gateway' in order "
+                "to define a QoS policy"
+            )
+            raise exceptions.CommandError(msg)
+
         if parsed_args.enable_ndp_proxy is not None:
             attrs['enable_ndp_proxy'] = parsed_args.enable_ndp_proxy
 
@@ -665,7 +684,7 @@ class DeleteRouter(command.Command):
 
         if result > 0:
             total = len(parsed_args.router)
-            msg = _("%(result)s of %(total)s routers failed " "to delete.") % {
+            msg = _("%(result)s of %(total)s routers failed to delete.") % {
                 'result': result,
                 'total': total,
             }
@@ -716,14 +735,14 @@ class ListRouter(command.Lister):
         identity_client = self.app.client_manager.identity
         client = self.app.client_manager.network
 
-        columns = (
+        columns: tuple[str, ...] = (
             'id',
             'name',
             'status',
             'is_admin_state_up',
             'project_id',
         )
-        column_headers = (
+        column_headers: tuple[str, ...] = (
             'ID',
             'Name',
             'Status',
@@ -769,27 +788,27 @@ class ListRouter(command.Lister):
                 d.is_distributed is not None
                 and 'is_distributed' not in columns
             ):
-                columns = columns + ('is_distributed',)
-                column_headers = column_headers + ('Distributed',)
+                columns += ('is_distributed',)
+                column_headers += ('Distributed',)
             if d.is_ha is not None and 'is_ha' not in columns:
-                columns = columns + ('is_ha',)
-                column_headers = column_headers + ('HA',)
+                columns += ('is_ha',)
+                column_headers += ('HA',)
         if parsed_args.long:
-            columns = columns + (
+            columns += (
                 'routes',
                 'external_gateway_info',
             )
-            column_headers = column_headers + (
+            column_headers += (
                 'Routes',
                 'External gateway info',
             )
             # availability zone will be available only when
             # router_availability_zone extension is enabled
             if client.find_extension("router_availability_zone"):
-                columns = columns + ('availability_zones',)
-                column_headers = column_headers + ('Availability zones',)
-            columns = columns + ('tags',)
-            column_headers = column_headers + ('Tags',)
+                columns += ('availability_zones',)
+                column_headers += ('Availability zones',)
+            columns += ('tags',)
+            column_headers += ('Tags',)
 
         return (
             column_headers,
@@ -921,7 +940,7 @@ class SetRouter(common.NeutronCommandWithExtraArgs):
             default=None,
             required_keys=['destination', 'gateway'],
             help=_(
-                "Add routes to the router "
+                "Add routes to the router. "
                 "destination: destination subnet (in CIDR notation) "
                 "gateway: nexthop IP address "
                 "(repeat option to add multiple routes). "
@@ -945,7 +964,7 @@ class SetRouter(common.NeutronCommandWithExtraArgs):
             '--ha',
             action='store_true',
             help=_(
-                "Set the router as highly available " "(disabled router only)"
+                "Set the router as highly available (disabled router only)"
             ),
         )
         routes_ha.add_argument(
@@ -961,7 +980,7 @@ class SetRouter(common.NeutronCommandWithExtraArgs):
             metavar="<network>",
             action='append',
             help=_(
-                "External Network used as router's gateway (name or ID). "
+                "External Network used as router's gateway (name or ID) "
                 "(repeat option to set multiple gateways per router "
                 "if the L3 service plugin in use supports it)."
             ),
@@ -977,7 +996,7 @@ class SetRouter(common.NeutronCommandWithExtraArgs):
                 "Desired IP and/or subnet (name or ID) "
                 "on external gateway: "
                 "subnet=<subnet>,ip-address=<ip-address> "
-                "(repeat option to set multiple fixed IP addresses)."
+                "(repeat option to set multiple fixed IP addresses)"
             ),
         )
         snat_group = parser.add_mutually_exclusive_group()
@@ -1157,7 +1176,7 @@ class UnsetRouter(common.NeutronUnsetCommandWithExtraArgs):
             default=None,
             required_keys=['destination', 'gateway'],
             help=_(
-                "Routes to be removed from the router "
+                "Routes to be removed from the router. "
                 "destination: destination subnet (in CIDR notation) "
                 "gateway: nexthop IP address "
                 "(repeat option to unset multiple routes)"
@@ -1210,7 +1229,7 @@ class UnsetRouter(common.NeutronUnsetCommandWithExtraArgs):
                 ):
                     pass
             except (KeyError, TypeError):
-                msg = _("Router does not have external network or qos policy")
+                msg = _("Router does not have external network or QoS policy")
                 raise exceptions.CommandError(msg)
             else:
                 attrs['external_gateway_info'] = {
@@ -1247,13 +1266,12 @@ class AddGatewayToRouter(command.ShowOne):
         parser.add_argument(
             'router',
             metavar="<router>",
-            help=_("Router to modify (name or ID)."),
+            help=_("Router to modify (name or ID)"),
         )
         parser.add_argument(
             metavar="<network>",
             help=_(
-                "External Network to a attach a router gateway to (name or "
-                "ID)."
+                "External Network to a attach a router gateway to (name or ID)"
             ),
             dest='external_gateways',
             # The argument is stored in a list in order to reuse the
@@ -1270,7 +1288,7 @@ class AddGatewayToRouter(command.ShowOne):
                 "Desired IP and/or subnet (name or ID) "
                 "on external gateway: "
                 "subnet=<subnet>,ip-address=<ip-address> "
-                "(repeat option to set multiple fixed IP addresses)."
+                "(repeat option to set multiple fixed IP addresses)"
             ),
         )
         return parser
@@ -1320,8 +1338,7 @@ class RemoveGatewayFromRouter(command.ShowOne):
         parser.add_argument(
             metavar="<network>",
             help=_(
-                "External Network to remove a router gateway from (name or "
-                "ID)."
+                "External Network to remove a router gateway from (name or ID)"
             ),
             dest='external_gateways',
             # The argument is stored in a list in order to reuse the
@@ -1338,7 +1355,7 @@ class RemoveGatewayFromRouter(command.ShowOne):
                 "IP and/or subnet (name or ID) on the external gateway "
                 "which is used to identify a particular gateway if multiple "
                 "are attached to the same network: subnet=<subnet>,"
-                "ip-address=<ip-address>."
+                "ip-address=<ip-address>"
             ),
         )
         return parser
