@@ -30,10 +30,9 @@ LOG = logging.getLogger(__name__)
 
 
 def _get_columns(item):
-    column_map = {}
-    hidden_columns = ['location', 'tenant_id']
+    hidden_columns = ['location', 'name', 'tenant_id', 'tags']
     return utils.get_osc_show_columns_for_sdk_resource(
-        item, column_map, hidden_columns
+        item, {}, hidden_columns
     )
 
 
@@ -428,6 +427,14 @@ class ListSecurityGroupRule(common.NetworkAndComputeLister):
                 _("**Deprecated** This argument is no longer needed")
             ),
         )
+        parser.add_argument(
+            '--project',
+            metavar='<project>',
+            help=self.enhance_help_neutron(_("Owner's project (name or ID)")),
+        )
+        identity_common.add_project_domain_option_to_parser(
+            parser, enhance_help=self.enhance_help_neutron
+        )
         return parser
 
     def update_parser_compute(self, parser):
@@ -451,7 +458,7 @@ class ListSecurityGroupRule(common.NetworkAndComputeLister):
         return parser
 
     def _get_column_headers(self, parsed_args):
-        column_headers = (
+        column_headers: tuple[str, ...] = (
             'ID',
             'IP Protocol',
             'Ethertype',
@@ -461,9 +468,9 @@ class ListSecurityGroupRule(common.NetworkAndComputeLister):
             'Remote Security Group',
         )
         if self.is_neutron:
-            column_headers = column_headers + ('Remote Address Group',)
+            column_headers += ('Remote Address Group',)
         if parsed_args.group is None:
-            column_headers = column_headers + ('Security Group',)
+            column_headers += ('Security Group',)
         return column_headers
 
     def take_action_network(self, client, parsed_args):
@@ -474,7 +481,7 @@ class ListSecurityGroupRule(common.NetworkAndComputeLister):
             self.log.warning(msg)
 
         column_headers = self._get_column_headers(parsed_args)
-        columns = (
+        columns: tuple[str, ...] = (
             'id',
             'protocol',
             'ether_type',
@@ -496,7 +503,7 @@ class ListSecurityGroupRule(common.NetworkAndComputeLister):
             ).id
             query = {'security_group_id': security_group_id}
         else:
-            columns = columns + ('security_group_id',)
+            columns += ('security_group_id',)
 
         if parsed_args.ingress:
             query['direction'] = 'ingress'
@@ -504,6 +511,15 @@ class ListSecurityGroupRule(common.NetworkAndComputeLister):
             query['direction'] = 'egress'
         if parsed_args.protocol is not None:
             query['protocol'] = parsed_args.protocol
+        if parsed_args.project is not None:
+            identity_client = self.app.client_manager.identity
+            project_id = identity_common.find_project(
+                identity_client,
+                parsed_args.project,
+                parsed_args.project_domain,
+            ).id
+            query['tenant_id'] = project_id
+            query['project_id'] = project_id
 
         rules = [
             self._format_network_security_group_rule(r)
@@ -523,7 +539,7 @@ class ListSecurityGroupRule(common.NetworkAndComputeLister):
 
     def take_action_compute(self, client, parsed_args):
         column_headers = self._get_column_headers(parsed_args)
-        columns = (
+        columns: tuple[str, ...] = (
             "ID",
             "IP Protocol",
             "Ethertype",
@@ -539,7 +555,7 @@ class ListSecurityGroupRule(common.NetworkAndComputeLister):
             )
             rules_to_list = security_group['rules']
         else:
-            columns = columns + ('parent_group_id',)
+            columns += ('parent_group_id',)
             for security_group in compute_v2.list_security_groups(
                 client, all_projects=parsed_args.all_projects
             ):
@@ -608,7 +624,7 @@ class ShowSecurityGroupRule(common.NetworkAndComputeShowOne):
 
         if obj is None:
             msg = (
-                _("Could not find security group rule " "with ID '%s'")
+                _("Could not find security group rule with ID '%s'")
                 % parsed_args.rule
             )
             raise exceptions.CommandError(msg)
