@@ -16,55 +16,51 @@
 
 """Command-line interface to the OpenStack APIs"""
 
-import locale
 import sys
+import warnings
 
 from osc_lib.api import auth
+from osc_lib.command import commandmanager
 from osc_lib import shell
-from oslo_utils import importutils
-import six
 
 import openstackclient
-from openstackclient.common import client_config as cloud_config
 from openstackclient.common import clientmanager
-from openstackclient.common import commandmanager
-
-osprofiler_profiler = importutils.try_import("osprofiler.profiler")
 
 
 DEFAULT_DOMAIN = 'default'
 
 
 class OpenStackShell(shell.OpenStackShell):
-
     def __init__(self):
-
-        super(OpenStackShell, self).__init__(
+        super().__init__(
             description=__doc__.strip(),
             version=openstackclient.__version__,
             command_manager=commandmanager.CommandManager('openstack.cli'),
-            deferred_help=True)
+            deferred_help=True,
+        )
 
         self.api_version = {}
 
         # Assume TLS host certificate verification is enabled
         self.verify = True
 
+        # ignore warnings from openstacksdk since our users can't do anything
+        # about them
+        warnings.filterwarnings('ignore', module='openstack')
+
     def build_option_parser(self, description, version):
-        parser = super(OpenStackShell, self).build_option_parser(
-            description,
-            version)
+        parser = super().build_option_parser(description, version)
         parser = clientmanager.build_plugin_option_parser(parser)
         parser = auth.build_auth_plugins_option_parser(parser)
         return parser
 
     def _final_defaults(self):
-        super(OpenStackShell, self)._final_defaults()
+        super()._final_defaults()
 
-        # Set the default plugin to token_endpoint if url and token are given
-        if (self.options.url and self.options.token):
-            # Use service token authentication
-            self._auth_type = 'token_endpoint'
+        # Set the default plugin to admin_token if endpoint and token are given
+        if self.options.endpoint and self.options.token:
+            # Use token authentication
+            self._auth_type = 'admin_token'
         else:
             self._auth_type = 'password'
 
@@ -76,7 +72,9 @@ class OpenStackShell(shell.OpenStackShell):
         # Loop through extensions to get API versions
         for mod in clientmanager.PLUGIN_MODULES:
             default_version = getattr(mod, 'DEFAULT_API_VERSION', None)
-            option = mod.API_VERSION_OPTION.replace('os_', '')
+            # Only replace the first instance of "os", some service names will
+            # have "os" in their name, like: "antiddos"
+            option = mod.API_VERSION_OPTION.replace('os_', '', 1)
             version_opt = str(self.cloud.config.get(option, default_version))
             if version_opt:
                 api = mod.API_NAME
@@ -90,13 +88,35 @@ class OpenStackShell(shell.OpenStackShell):
                     # this throws an exception if invalid
                     skip_old_check = mod_check_api_version(version_opt)
 
+                # NOTE(stephenfin): API_VERSIONS has traditionally been a
+                # dictionary but the values are only used internally and are
+                # ignored for the modules using SDK. So we now support tuples
+                # instead.
                 mod_versions = getattr(mod, 'API_VERSIONS', None)
-                if not skip_old_check and mod_versions:
+                if mod_versions is not None and not isinstance(
+                    mod_versions, dict | tuple
+                ):
+                    raise TypeError(
+                        f'Plugin {mod} has incompatible API_VERSIONS. '
+                        f'Expected: tuple, dict. Got: {type(mod_versions)}. '
+                        f'Please report this to your package maintainer.'
+                    )
+
+                if mod_versions and not skip_old_check:
                     if version_opt not in mod_versions:
+                        sorted_versions = sorted(
+                            list(mod.API_VERSIONS),
+                            key=lambda s: list(map(int, s.split('.'))),
+                        )
                         self.log.warning(
-                            "%s version %s is not in supported versions %s"
-                            % (api, version_opt,
-                               ', '.join(list(mod.API_VERSIONS.keys()))))
+                            "%(name)s API version %(version)s is not in "
+                            "supported versions: %(supported)s",
+                            {
+                                'name': api,
+                                'version': version_opt,
+                                'supported': ', '.join(sorted_versions),
+                            },
+                        )
 
                 # Command groups deal only with major versions
                 version = '.v' + version_opt.replace('.', '_').split('_')[0]
@@ -104,7 +124,7 @@ class OpenStackShell(shell.OpenStackShell):
                 self.command_manager.add_command_group(cmd_group)
                 self.log.debug(
                     '%(name)s API version %(version)s, cmd group %(group)s',
-                    {'name': api, 'version': version_opt, 'group': cmd_group}
+                    {'name': api, 'version': version_opt, 'group': cmd_group},
                 )
 
     def _load_commands(self):
@@ -113,8 +133,7 @@ class OpenStackShell(shell.OpenStackShell):
         osc-lib has no opinion on what commands should be loaded
         """
         # Commands that span multiple APIs
-        self.command_manager.add_command_group(
-            'openstack.common')
+        self.command_manager.add_command_group('openstack.common')
 
         # This is the naive extension implementation referred to in
         # blueprint 'client-extensions'
@@ -126,87 +145,25 @@ class OpenStackShell(shell.OpenStackShell):
         #         'show_repo=qaz.github.repo:ShowRepo',
         #     ],
         # }
-        self.command_manager.add_command_group(
-            'openstack.extension')
+        self.command_manager.add_command_group('openstack.extension')
 
     def initialize_app(self, argv):
-        super(OpenStackShell, self).initialize_app(argv)
+        super().initialize_app(argv)
 
-        # Argument precedence is really broken in multiple places
-        # so we're just going to fix it here until o-c-c and osc-lib
-        # get sorted out.
-        # TODO(dtroyer): remove when os-client-config and osc-lib are fixed
-
-        # First, throw away what has already been done with o-c-c and
-        # use our own.
-        try:
-            self.cloud_config = cloud_config.OSC_Config(
-                override_defaults={
-                    'interface': None,
-                    'auth_type': self._auth_type,
-                },
-            )
-        except (IOError, OSError) as e:
-            self.log.critical("Could not read clouds.yaml configuration file")
-            self.print_help_if_requested()
-            raise e
-
-        if not self.options.debug:
-            self.options.debug = None
-
-        # NOTE(dtroyer): Need to do this with validate=False to defer the
-        #                auth plugin handling to ClientManager.setup_auth()
-        self.cloud = self.cloud_config.get_one_cloud(
-            cloud=self.options.cloud,
-            argparse=self.options,
-            validate=False,
-        )
-
-        # Then, re-create the client_manager with the correct arguments
+        # Re-create the client_manager with our subclass
         self.client_manager = clientmanager.ClientManager(
             cli_options=self.cloud,
             api_version=self.api_version,
+            pw_func=shell.prompt_for_password,
         )
 
-    def prepare_to_run_command(self, cmd):
-        """Set up auth and API versions"""
-
-        # TODO(dtroyer): Move this to osc-lib
-        # NOTE(dtroyer): If auth is not required for a command, force fake
-        #                token auth so KSA plugins are happy
-
-        kwargs = {}
-        if not cmd.auth_required:
-            # Build fake token creds to keep ksa and o-c-c hushed
-            kwargs['auth_type'] = 'token_endpoint'
-            kwargs['auth'] = {}
-            kwargs['auth']['token'] = 'x'
-            kwargs['auth']['url'] = 'x'
-
-        # Validate auth options
-        self.cloud = self.cloud_config.get_one_cloud(
-            cloud=self.options.cloud,
-            argparse=self.options,
-            validate=True,
-            **kwargs
-        )
-        # Push the updated args into ClientManager
-        self.client_manager._cli_options = self.cloud
-
-        return super(OpenStackShell, self).prepare_to_run_command(cmd)
-
 
 def main(argv=None):
     if argv is None:
         argv = sys.argv[1:]
-        if six.PY2:
-            # Emulate Py3, decode argv into Unicode based on locale so that
-            # commands always see arguments as text instead of binary data
-            encoding = locale.getpreferredencoding()
-            if encoding:
-                argv = map(lambda arg: arg.decode(encoding), argv)
 
     return OpenStackShell().run(argv)
 
+
 if __name__ == "__main__":
     sys.exit(main())
