@@ -14,11 +14,10 @@ from openstackclient.tests.functional.identity.v2 import common
 
 
 class TokenTests(common.IdentityTests):
-
     def test_token_issue(self):
         self._create_dummy_token()
 
     def test_token_revoke(self):
         token_id = self._create_dummy_token(add_clean_up=False)
-        raw_output = self.openstack('token revoke %s' % token_id)
+        raw_output = self.openstack(f'token revoke {token_id}')
         self.assertEqual(0, len(raw_output))
