@@ -30,9 +30,7 @@ class TestNDPProxy(network_fakes.TestNetworkV2):
         # Get a shortcut to the DomainManager Mock
         self.domains_mock = self.identity_client.domains
 
-        self.router = network_fakes.FakeRouter.create_one_router(
-            {'id': 'fake-router-id'}
-        )
+        self.router = network_fakes.create_one_router({'id': 'fake-router-id'})
         self.network_client.find_router = mock.Mock(return_value=self.router)
         self.port = network_fakes.create_one_port()
         self.network_client.find_port = mock.Mock(return_value=self.port)
@@ -313,7 +311,7 @@ class TestListNDPProxy(TestNDPProxy):
             **{'project_id': project.id}
         )
         self.assertEqual(self.columns, columns)
-        self.assertItemsEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_ndp_proxy_list_project_domain(self):
         project = identity_fakes_v3.FakeProject.create_one_project()
@@ -334,7 +332,7 @@ class TestListNDPProxy(TestNDPProxy):
 
         self.network_client.ndp_proxies.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
-        self.assertItemsEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
 
 class TestSetNDPProxy(TestNDPProxy):
