@@ -62,7 +62,7 @@ class TestCase(testtools.TestCase):
 
         if m.called:
             if not msg:
-                msg = 'method %s should not have been called' % m
+                msg = f'method {m} should not have been called'
             self.fail(msg)
 
 
@@ -90,11 +90,17 @@ class TestCommand(TestCase):
                 argparse.ArgumentError,
             ):
                 raise ParserException(
-                    "Argument parse failed: %s" % stderr.getvalue()
+                    f"Argument parse failed: {stderr.getvalue()}"
                 )
         for av in verify_args:
-            attr, value = av
+            attr, expected_value = av
             if attr:
+                actual_value = getattr(parsed_args, attr)
                 self.assertIn(attr, parsed_args)
-                self.assertEqual(value, getattr(parsed_args, attr))
+                self.assertEqual(
+                    expected_value,
+                    actual_value,
+                    f'args.{attr}: expected: {expected_value}, got: '
+                    f'{actual_value}',
+                )
         return parsed_args
