@@ -17,7 +17,6 @@
 import functools
 import logging
 
-from cinderclient import api_versions
 from cliff import columns as cliff_columns
 from osc_lib.cli import format_columns
 from osc_lib.cli import parseractions
@@ -44,7 +43,7 @@ class EncryptionInfoColumn(cliff_columns.FormattableColumn):
     """
 
     def __init__(self, value, encryption_data=None):
-        super(EncryptionInfoColumn, self).__init__(value)
+        super().__init__(value)
         self._encryption_data = encryption_data or {}
 
     def _get_encryption_info(self):
@@ -110,7 +109,7 @@ class CreateVolumeType(command.ShowOne):
     _description = _("Create new volume type")
 
     def get_parser(self, prog_name):
-        parser = super(CreateVolumeType, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             "name",
             metavar="<name>",
@@ -172,7 +171,7 @@ class CreateVolumeType(command.ShowOne):
             default=False,
             help=_(
                 "Enabled replication for this volume type "
-                "(this is an alias for '--property replication_enabled=<is> True') "  # noqa: E501
+                "(this is an alias for '--property replication_enabled=<is> True') "
                 "(requires driver support)"
             ),
         )
@@ -182,7 +181,7 @@ class CreateVolumeType(command.ShowOne):
             dest='availability_zones',
             help=_(
                 "Set an availability zone for this volume type "
-                "(this is an alias for '--property RESKEY:availability_zones:<az>') "  # noqa: E501
+                "(this is an alias for '--property RESKEY:availability_zones:<az>') "
                 "(repeat option to set multiple availability zones)"
             ),
         )
@@ -273,8 +272,7 @@ class CreateVolumeType(command.ShowOne):
                 )
             except Exception as e:
                 msg = _(
-                    "Failed to add project %(project)s access to "
-                    "type: %(e)s"
+                    "Failed to add project %(project)s access to type: %(e)s"
                 )
                 LOG.error(msg % {'project': parsed_args.project, 'e': e})
 
@@ -331,7 +329,7 @@ class DeleteVolumeType(command.Command):
     _description = _("Delete volume type(s)")
 
     def get_parser(self, prog_name):
-        parser = super(DeleteVolumeType, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             "volume_types",
             metavar="<volume-type>",
@@ -364,7 +362,7 @@ class DeleteVolumeType(command.Command):
         if result > 0:
             total = len(parsed_args.volume_types)
             msg = _(
-                "%(result)s of %(total)s volume types failed " "to delete."
+                "%(result)s of %(total)s volume types failed to delete."
             ) % {'result': result, 'total': total}
             raise exceptions.CommandError(msg)
 
@@ -373,7 +371,7 @@ class ListVolumeType(command.Lister):
     _description = _("List volume types")
 
     def get_parser(self, prog_name):
-        parser = super(ListVolumeType, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             '--long',
             action='store_true',
@@ -409,59 +407,6 @@ class ListVolumeType(command.Lister):
                 "(admin only)"
             ),
         )
-        parser.add_argument(
-            '--property',
-            metavar='<key=value>',
-            action=parseractions.KeyValueAction,
-            dest='properties',
-            help=_(
-                'Filter by a property on the volume types '
-                '(repeat option to filter by multiple properties) '
-                '(admin only except for user-visible extra specs) '
-                '(supported by --os-volume-api-version 3.52 or above)'
-            ),
-        )
-        parser.add_argument(
-            '--multiattach',
-            action='store_true',
-            default=False,
-            help=_(
-                "List only volume types with multi-attach enabled "
-                "(this is an alias for '--property multiattach=<is> True') "
-                "(supported by --os-volume-api-version 3.52 or above)"
-            ),
-        )
-        parser.add_argument(
-            '--cacheable',
-            action='store_true',
-            default=False,
-            help=_(
-                "List only volume types with caching enabled "
-                "(this is an alias for '--property cacheable=<is> True') "
-                "(admin only) "
-                "(supported by --os-volume-api-version 3.52 or above)"
-            ),
-        )
-        parser.add_argument(
-            '--replicated',
-            action='store_true',
-            default=False,
-            help=_(
-                "List only volume types with replication enabled "
-                "(this is an alias for '--property replication_enabled=<is> True') "  # noqa: E501
-                "(supported by --os-volume-api-version 3.52 or above)"
-            ),
-        )
-        parser.add_argument(
-            '--availability-zone',
-            action='append',
-            dest='availability_zones',
-            help=_(
-                "List only volume types with this availability configured "
-                "(this is an alias for '--property RESKEY:availability_zones:<az>') "  # noqa: E501
-                "(repeat option to filter on multiple availability zones)"
-            ),
-        )
         return parser
 
     def take_action(self, parsed_args):
@@ -473,14 +418,12 @@ class ListVolumeType(command.Lister):
                 'Name',
                 'Is Public',
                 'Description',
-                'Extra Specs',
             ]
             column_headers = [
                 'ID',
                 'Name',
                 'Is Public',
                 'Description',
-                'Properties',
             ]
         else:
             columns = ['ID', 'Name', 'Is Public']
@@ -489,33 +432,7 @@ class ListVolumeType(command.Lister):
         if parsed_args.default:
             data = [volume_client.volume_types.default()]
         else:
-            search_opts = {}
-            properties = {}
-            if parsed_args.properties:
-                properties.update(parsed_args.properties)
-            if parsed_args.multiattach:
-                properties['multiattach'] = '<is> True'
-            if parsed_args.cacheable:
-                properties['cacheable'] = '<is> True'
-            if parsed_args.replicated:
-                properties['replication_enabled'] = '<is> True'
-            if parsed_args.availability_zones:
-                properties['RESKEY:availability_zones'] = ','.join(
-                    parsed_args.availability_zones
-                )
-            if properties:
-                if volume_client.api_version < api_versions.APIVersion('3.52'):
-                    msg = _(
-                        "--os-volume-api-version 3.52 or greater is required "
-                        "to use the '--property' option or any of the alias "
-                        "options"
-                    )
-                    raise exceptions.CommandError(msg)
-
-                search_opts['extra_specs'] = properties
-
             data = volume_client.volume_types.list(
-                search_opts=search_opts,
                 is_public=parsed_args.is_public,
             )
 
@@ -565,7 +482,7 @@ class SetVolumeType(command.Command):
     _description = _("Set volume type properties")
 
     def get_parser(self, prog_name):
-        parser = super(SetVolumeType, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'volume_type',
             metavar='<volume-type>',
@@ -617,7 +534,7 @@ class SetVolumeType(command.Command):
             default=False,
             help=_(
                 "Enabled replication for this volume type "
-                "(this is an alias for '--property replication_enabled=<is> True') "  # noqa: E501
+                "(this is an alias for '--property replication_enabled=<is> True') "
                 "(requires driver support)"
             ),
         )
@@ -627,7 +544,7 @@ class SetVolumeType(command.Command):
             dest='availability_zones',
             help=_(
                 "Set an availability zone for this volume type "
-                "(this is an alias for '--property RESKEY:availability_zones:<az>') "  # noqa: E501
+                "(this is an alias for '--property RESKEY:availability_zones:<az>') "
                 "(repeat option to set multiple availability zones)"
             ),
         )
@@ -635,8 +552,7 @@ class SetVolumeType(command.Command):
             '--project',
             metavar='<project>',
             help=_(
-                'Set volume type access to project (name or ID) '
-                '(admin only)'
+                'Set volume type access to project (name or ID) (admin only)'
             ),
         )
         public_group = parser.add_mutually_exclusive_group()
@@ -728,17 +644,12 @@ class SetVolumeType(command.Command):
                 volume_client.volume_types.update(volume_type.id, **kwargs)
             except Exception as e:
                 LOG.error(
-                    _(
-                        "Failed to update volume type name or"
-                        " description: %s"
-                    ),
+                    _("Failed to update volume type name or description: %s"),
                     e,
                 )
                 result += 1
 
-        properties = {}
-
-        properties = {}
+        properties: dict[str, str] = {}
         if parsed_args.properties:
             properties.update(parsed_args.properties)
         if parsed_args.multiattach:
@@ -772,7 +683,7 @@ class SetVolumeType(command.Command):
                 )
             except Exception as e:
                 LOG.error(
-                    _("Failed to set volume type access to " "project: %s"), e
+                    _("Failed to set volume type access to project: %s"), e
                 )
                 result += 1
 
@@ -796,7 +707,7 @@ class SetVolumeType(command.Command):
 
         if result > 0:
             raise exceptions.CommandError(
-                _("Command Failed: One or more of" " the operations failed")
+                _("Command Failed: One or more of the operations failed")
             )
 
 
@@ -804,7 +715,7 @@ class ShowVolumeType(command.ShowOne):
     _description = _("Display volume type details")
 
     def get_parser(self, prog_name):
-        parser = super(ShowVolumeType, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             "volume_type",
             metavar="<volume-type>",
@@ -875,7 +786,7 @@ class UnsetVolumeType(command.Command):
     _description = _("Unset volume type properties")
 
     def get_parser(self, prog_name):
-        parser = super(UnsetVolumeType, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'volume_type',
             metavar='<volume-type>',
@@ -904,8 +815,7 @@ class UnsetVolumeType(command.Command):
             "--encryption-type",
             action="store_true",
             help=_(
-                "Remove the encryption type for this volume type "
-                "(admin only)"
+                "Remove the encryption type for this volume type (admin only)"
             ),
         )
         return parser
@@ -941,10 +851,7 @@ class UnsetVolumeType(command.Command):
                 )
             except Exception as e:
                 LOG.error(
-                    _(
-                        "Failed to remove volume type access from "
-                        "project: %s"
-                    ),
+                    _("Failed to remove volume type access from project: %s"),
                     e,
                 )
                 result += 1
@@ -963,5 +870,5 @@ class UnsetVolumeType(command.Command):
 
         if result > 0:
             raise exceptions.CommandError(
-                _("Command Failed: One or more of" " the operations failed")
+                _("Command Failed: One or more of the operations failed")
             )
